{% load cms_tags %}
{% with tag_type=instance.tag_type css_classes=instance.css_classes inline_styles=instance.inline_styles %}
<{{ tag_type }}{% if css_classes %} class="{{ css_classes }}"{% endif %}{% if inline_styles %} style="{{ inline_styles }}"{% endif %}>
{% for plugin in instance.child_plugin_instances %}
	{% render_plugin plugin %}
{% endfor %}
</{{ tag_type }}>
{% endwith %}