{% extends change_form_template|default:"admin/cms/usersettings/change_form.html" %}
{% load admin_static i18n %}

{% block extrahead %}
	<link rel="stylesheet" type="text/css" href="{% static "css/cms.bootstrap.css" %}" />
	<link rel="stylesheet" type="text/css" href="//netdna.bootstrapcdn.com/bootstrap/3.0.3/css/bootstrap.min.css" />
	<link rel="stylesheet" type="text/css" href="//netdna.bootstrapcdn.com/font-awesome/3.2.1/css/font-awesome.min.css" />
	<script type="text/javascript" src="{% static "admin/js/jquery.js" %}"></script>
	<script type="text/javascript" src="{% static "admin/js/jquery.init.js" %}"></script>
{% endblock %}

{% block field_sets %}{% with line=adminform.first_field %}
<div class="container">
	{{ line.errors }}
	{{ line }}
{% if not line.value %}
	<div class="row">
		<div class="col-xs-12">
			<h3>{% trans "There are no further settings for this plugin" %}</h3>
			<p>{% trans "Please hit OK to save." %}</p>
		</div>
	</div>
{% endif %}
</div>
{% endwith %}{% endblock field_sets %}
