{% load bootstrap3_tags %}
{% for child in children %}
<li class="{% if child.selected or child.ancestor %}active{% endif %}{% if child.children %} dropdown{% endif %}">
	{% if child.children %}
	<a href="#" class="dropdown" data-toggle="dropdown">{{ child.get_menu_title }}<b class="caret"></b></a>
	<ul class="dropdown-menu">
		<li>
			<a href="{{ child.attr.redirect_url|default:child.get_absolute_url }}"><strong>{{ child.get_menu_title }}</strong></a>
		</li>
		<li class="divider"></li>
		{% main_menu from_level to_level template "" "" child %}
	</ul>
	{% else %}
	<a href="{{ child.attr.redirect_url|default:child.get_absolute_url }}">{{ child.get_menu_title }}</a>
	{% endif %}
</li>
{% endfor %}
